@@ -1,6 +1,6 @@
 package Math::Vector::Real::kdTree;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use 5.010;
 use strict;
@@ -49,11 +49,16 @@ sub at {
 }
 
 sub insert {
-    my ($self, $v) = @_;
+    my $self = shift;
+    return undef unless @_;
     my $vs = $self->{vs};
-    $v = Math::Vector::Real::clone($v);
-    push @$vs, $v;
-    _insert($vs, $self->{tree}, $#$vs)
+    my $ix = @$vs;
+    for (@_) {
+        my $v = Math::Vector::Real::clone($_);
+        push @$vs, $v;
+        _insert($vs, $self->{tree}, $#$vs)
+    }
+    $ix;
 }
 
 sub _insert {
@@ -100,7 +105,6 @@ sub move {
     _insert($vs, $t, $ix);
 }
 
-
 sub _delete {
     my ($vs, $t, $ix) = @_;
     if (defined $t->[0]) {
@@ -415,9 +419,11 @@ The following methods are provided:
 
 Creates a new kdTree containing the gived points.
 
-=item $t->insert($p)
+=item my $ix = $t->insert($p0, $p1, ...)
 
-Inserts the given point into the kdTree.
+Inserts the given points into the kdTree.
+
+Returns the index assigned to the first point inserted.
 
 =item $s = $t->size
 
